==> nextcloud-app-calendar-1.6.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/eo.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendaro",
    "Group" : "Grupo",
    "Unknown" : "Nekonata",
    "New event" : "Nova okazaĵo",
    "Share Calendar" : "Kunhavigi kalendaron",
    "Shared" : "Kunhavata",
    "group" : "grupo",
    "Attendees" : "Ĉeestontoj",
    "Repeating" : "Ripetata",
    "Global" : "Malloka",
    "None" : "Nenio",
    "never" : "neniam",
    "hours" : "horoj",
    "days" : "tagoj",
    "week" : "semajno",
    "Title of the Event" : "Okazaĵotitolo",
    "All day Event" : "Tuttaga okazaĵo",
    "Delete" : "Forigi",
    "Cancel" : "Nuligi",
    "More ..." : "Pli...",
    "Create" : "Krei",
    "Update" : "Ĝisdatigi",
    "Close" : "Fermi",
    "Location" : "Loko",
    "Description" : "Priskribo",
    "Export" : "Elporti",
    "Day" : "Tago",
    "Week" : "Semajno",
    "Month" : "Monato",
    "Today" : "Hodiaŭ",
    "More" : "Pli",
    "Edit" : "Redakti",
    "Link" : "Ligilo",
    "Download" : "Elŝuti",
    "can edit" : "povas redakti",
    "New Calendar" : "Nova kalendaro",
    "Name" : "Nomo",
    "Edit event" : "Redakti okazaĵon",
    "Time" : "Horo",
    "Type" : "Tipo",
    "Repeat" : "Ripeti",
    "Add" : "Aldoni",
    "from" : "el",
    "to" : "ĝis",
    "Import Calendars" : "Enporti kalendarojn",
    "New calendar" : "Nova kalendaro",
    "Import calendar" : "Enporti kalendaron",
    "No Calendars selected for import" : "Neniu kalendaro elektiĝis por enporti",
    "Primary CalDAV address" : "Ĉefa CalDAV-adreso",
    "iOS/OS X CalDAV address" : "CalDAV-adreso por iOS/OS X"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.6.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/eo.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendaro",
    "Hello," : "Saluton,",
    "Open »%s«" : "Malfermi »%s«",
    "Cheers!" : "Dankon",
    "Group" : "Grupo",
    "Room" : "Ĉambro",
    "Unknown" : "Nekonata",
    "Required" : "Nepra",
    "Optional" : "Malnepra",
    "{name} ({email})" : "{name} ({email})",
    "New event" : "Nova okazaĵo",
    "Share Calendar" : "Kunhavigi kalendaron",
    "Shared" : "Kunhavata",
    "Email sent." : "La retpoŝtaĵo sendiĝis.",
    "Could not send your email." : "Ne povis sendi vian retpoŝtaĵon.",
    "group" : "grupo",
    "Details" : "Detaloj",
    "Attendees" : "Ĉeestontoj",
    "Repeating" : "Ripetata",
    "Confirmed" : "Konfirmis",
    "Cancelled" : "Nuliĝis",
    "Please add a title." : "Bonvolu aldoni titolo",
    "Please select a calendar." : "Bonvolu elekti kalendaron.",
    "Global" : "Malloka",
    "None" : "Nenio",
    "Every day" : "Ĉiutage",
    "Every week" : "Ĉiusemajne",
    "Every month" : "Ĉiumonate",
    "Every year" : "Ĉiujare",
    "never" : "neniam",
    "Email" : "Retpoŝto",
    "hours" : "horoj",
    "days" : "tagoj",
    "week" : "semajno",
    "Title of the Event" : "Okazaĵotitolo",
    "All day Event" : "Tuttaga okazaĵo",
    "Delete" : "Forigi",
    "Cancel" : "Nuligi",
    "More ..." : "Pli...",
    "Create" : "Krei",
    "Update" : "Ĝisdatigi",
    "Close" : "Fermi",
    "Location" : "Loko",
    "Description" : "Priskribo",
    "Export" : "Elporti",
    "Day" : "Tago",
    "Week" : "Semajno",
    "Month" : "Monato",
    "Today" : "Hodiaŭ",
    "More" : "Pli",
    "Edit" : "Redakti",
    "Link" : "Ligilo",
    "Download" : "Elŝuti",
    "can edit" : "povas redakti",
    "Share link" : "Kunhavigi ligilon",
    "Email link to person" : "Retpoŝti la ligilon al ulo",
    "Send" : "Sendi",
    "New Calendar" : "Nova kalendaro",
    "Name" : "Nomo",
    "New Subscription" : "Nova abono",
    "Go back" : "Revenu",
    "Edit event" : "Redakti okazaĵon",
    "Time" : "Horo",
    "Type" : "Tipo",
    "Repeat" : "Ripeti",
    "Add" : "Aldoni",
    "from" : "el",
    "to" : "ĝis",
    "Import Calendars" : "Enporti kalendarojn",
    "Import canceled" : "Enporti nuliĝis",
    "New calendar" : "Nova kalendaro",
    "Import calendar" : "Enporti kalendaron",
    "No Calendars selected for import" : "Neniu kalendaro elektiĝis por enporti",
    "Primary CalDAV address" : "Ĉefa CalDAV-adreso",
    "Subscribe" : "Aboni"
},
"nplurals=2; plural=(n != 1);");
